@@ -17,6 +17,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import ros_cdk_core
@@ -33,7 +35,7 @@ class Domain(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "DomainProps",
+        props: typing.Union["DomainProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Create a new ``ALIYUN::DNS::Domain``.
@@ -47,39 +49,52 @@ class Domain(
         :param props: -
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union[DomainProps, typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrDnsServers")
     def attr_dns_servers(self) -> ros_cdk_core.IResolvable:
         '''Attribute DnsServers: The DNS list for the domain name under resolution.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrDnsServers"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrDomainId")
     def attr_domain_id(self) -> ros_cdk_core.IResolvable:
         '''Attribute DomainId: Domain ID.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrDomainId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrDomainName")
     def attr_domain_name(self) -> ros_cdk_core.IResolvable:
         '''Attribute DomainName: Domain name.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrDomainName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrGroupId")
     def attr_group_id(self) -> ros_cdk_core.IResolvable:
         '''Attribute GroupId: Domain name group ID.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrGroupId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrGroupName")
     def attr_group_name(self) -> ros_cdk_core.IResolvable:
         '''Attribute GroupName: The name of the domain name group.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrGroupName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrPunyCode")
     def attr_puny_code(self) -> ros_cdk_core.IResolvable:
         '''Attribute PunyCode: punycode returned only for a Chinese domain name.'''
@@ -97,7 +112,7 @@ class DomainGroup(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "DomainGroupProps",
+        props: typing.Union["DomainGroupProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Create a new ``ALIYUN::DNS::DomainGroup``.
@@ -111,9 +126,22 @@ class DomainGroup(
         :param props: -
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union[DomainGroupProps, typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrGroupId")
     def attr_group_id(self) -> ros_cdk_core.IResolvable:
         '''Attribute GroupId: Domain name group ID.'''
@@ -135,6 +163,14 @@ class DomainGroupProps:
 
         :param group_name: Property groupName: Domain name group name.
         '''
+        if __debug__:
+            def stub(
+                *,
+                group_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument group_name", value=group_name, expected_type=type_hints["group_name"])
         self._values: typing.Dict[str, typing.Any] = {
             "group_name": group_name,
         }
@@ -175,7 +211,7 @@ class DomainProps:
         domain_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
         group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-        tags: typing.Optional[typing.Sequence["RosDomain.TagsProperty"]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union["RosDomain.TagsProperty", typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::DNS::Domain``.
 
@@ -184,6 +220,20 @@ class DomainProps:
         :param resource_group_id: Property resourceGroupId: Resource group id.
         :param tags: Property tags: Tags to attach to instance. Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
         '''
+        if __debug__:
+            def stub(
+                *,
+                domain_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                tags: typing.Optional[typing.Sequence[typing.Union[RosDomain.TagsProperty, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
+            check_type(argname="argument group_id", value=group_id, expected_type=type_hints["group_id"])
+            check_type(argname="argument resource_group_id", value=resource_group_id, expected_type=type_hints["resource_group_id"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
         self._values: typing.Dict[str, typing.Any] = {
             "domain_name": domain_name,
         }
@@ -249,7 +299,7 @@ class DomainRecord(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "DomainRecordProps",
+        props: typing.Union["DomainRecordProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Create a new ``ALIYUN::DNS::DomainRecord``.
@@ -263,9 +313,22 @@ class DomainRecord(
         :param props: -
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union[DomainRecordProps, typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrRecordId")
     def attr_record_id(self) -> ros_cdk_core.IResolvable:
         '''Attribute RecordId: Parse the ID of the record.'''
@@ -307,6 +370,26 @@ class DomainRecordProps:
         :param priority: Property priority: The priority of the MX record, the value range [1,10], when the record type is MX record, this parameter must be.
         :param ttl: Property ttl: The resolution time is valid. The default is 600 seconds (10 minutes). See the TTL definition.
         '''
+        if __debug__:
+            def stub(
+                *,
+                domain_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                rr: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                line: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                priority: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                ttl: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
+            check_type(argname="argument rr", value=rr, expected_type=type_hints["rr"])
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+            check_type(argname="argument line", value=line, expected_type=type_hints["line"])
+            check_type(argname="argument priority", value=priority, expected_type=type_hints["priority"])
+            check_type(argname="argument ttl", value=ttl, expected_type=type_hints["ttl"])
         self._values: typing.Dict[str, typing.Any] = {
             "domain_name": domain_name,
             "rr": rr,
@@ -401,7 +484,7 @@ class RosDomain(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "RosDomainProps",
+        props: typing.Union["RosDomainProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
         '''Create a new ``ALIYUN::DNS::Domain``.
@@ -411,6 +494,19 @@ class RosDomain(
         :param props: - resource properties.
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union[RosDomainProps, typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
     @jsii.member(jsii_name="renderProperties")
@@ -421,15 +517,20 @@ class RosDomain(
         '''
         :param props: -
         '''
+        if __debug__:
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="ROS_RESOURCE_TYPE_NAME")
     def ROS_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "ROS_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrDnsServers")
     def attr_dns_servers(self) -> ros_cdk_core.IResolvable:
         '''
@@ -437,7 +538,7 @@ class RosDomain(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrDnsServers"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrDomainId")
     def attr_domain_id(self) -> ros_cdk_core.IResolvable:
         '''
@@ -445,7 +546,7 @@ class RosDomain(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrDomainId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrDomainName")
     def attr_domain_name(self) -> ros_cdk_core.IResolvable:
         '''
@@ -453,7 +554,7 @@ class RosDomain(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrDomainName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrGroupId")
     def attr_group_id(self) -> ros_cdk_core.IResolvable:
         '''
@@ -461,7 +562,7 @@ class RosDomain(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrGroupId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrGroupName")
     def attr_group_name(self) -> ros_cdk_core.IResolvable:
         '''
@@ -469,7 +570,7 @@ class RosDomain(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrGroupName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrPunyCode")
     def attr_puny_code(self) -> ros_cdk_core.IResolvable:
         '''
@@ -477,12 +578,12 @@ class RosDomain(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrPunyCode"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rosProperties")
     def _ros_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "rosProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="domainName")
     def domain_name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -495,18 +596,30 @@ class RosDomain(
         self,
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "domainName", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enableResourcePropertyConstraint")
     def enable_resource_property_constraint(self) -> builtins.bool:
         return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
 
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        if __debug__:
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="groupId")
     def group_id(
         self,
@@ -521,9 +634,16 @@ class RosDomain(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "groupId", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="resourceGroupId")
     def resource_group_id(
         self,
@@ -538,9 +658,16 @@ class RosDomain(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resourceGroupId", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="tags")
     def tags(self) -> typing.Optional[typing.List["RosDomain.TagsProperty"]]:
         '''
@@ -553,6 +680,13 @@ class RosDomain(
         self,
         value: typing.Optional[typing.List["RosDomain.TagsProperty"]],
     ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Optional[typing.List[RosDomain.TagsProperty]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tags", value)
 
     @jsii.data_type(
@@ -571,6 +705,16 @@ class RosDomain(
             :param key: 
             :param value: 
             '''
+            if __debug__:
+                def stub(
+                    *,
+                    key: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
+                check_type(argname="argument key", value=key, expected_type=type_hints["key"])
+                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
             self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
             }
@@ -619,7 +763,7 @@ class RosDomainGroup(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "RosDomainGroupProps",
+        props: typing.Union["RosDomainGroupProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
         '''Create a new ``ALIYUN::DNS::DomainGroup``.
@@ -629,6 +773,19 @@ class RosDomainGroup(
         :param props: - resource properties.
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union[RosDomainGroupProps, typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
     @jsii.member(jsii_name="renderProperties")
@@ -639,15 +796,20 @@ class RosDomainGroup(
         '''
         :param props: -
         '''
+        if __debug__:
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="ROS_RESOURCE_TYPE_NAME")
     def ROS_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "ROS_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrGroupId")
     def attr_group_id(self) -> ros_cdk_core.IResolvable:
         '''
@@ -655,21 +817,26 @@ class RosDomainGroup(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrGroupId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rosProperties")
     def _ros_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "rosProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enableResourcePropertyConstraint")
     def enable_resource_property_constraint(self) -> builtins.bool:
         return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
 
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        if __debug__:
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="groupName")
     def group_name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -682,6 +849,13 @@ class RosDomainGroup(
         self,
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "groupName", value)
 
 
@@ -700,6 +874,14 @@ class RosDomainGroupProps:
 
         :param group_name: 
         '''
+        if __debug__:
+            def stub(
+                *,
+                group_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument group_name", value=group_name, expected_type=type_hints["group_name"])
         self._values: typing.Dict[str, typing.Any] = {
             "group_name": group_name,
         }
@@ -742,7 +924,7 @@ class RosDomainProps:
         domain_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
         group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-        tags: typing.Optional[typing.Sequence[RosDomain.TagsProperty]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[RosDomain.TagsProperty, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::DNS::Domain``.
 
@@ -751,6 +933,20 @@ class RosDomainProps:
         :param resource_group_id: 
         :param tags: 
         '''
+        if __debug__:
+            def stub(
+                *,
+                domain_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                tags: typing.Optional[typing.Sequence[typing.Union[RosDomain.TagsProperty, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
+            check_type(argname="argument group_id", value=group_id, expected_type=type_hints["group_id"])
+            check_type(argname="argument resource_group_id", value=resource_group_id, expected_type=type_hints["resource_group_id"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
         self._values: typing.Dict[str, typing.Any] = {
             "domain_name": domain_name,
         }
@@ -821,7 +1017,7 @@ class RosDomainRecord(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "RosDomainRecordProps",
+        props: typing.Union["RosDomainRecordProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
         '''Create a new ``ALIYUN::DNS::DomainRecord``.
@@ -831,6 +1027,19 @@ class RosDomainRecord(
         :param props: - resource properties.
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union[RosDomainRecordProps, typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
     @jsii.member(jsii_name="renderProperties")
@@ -841,15 +1050,20 @@ class RosDomainRecord(
         '''
         :param props: -
         '''
+        if __debug__:
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="ROS_RESOURCE_TYPE_NAME")
     def ROS_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "ROS_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrRecordId")
     def attr_record_id(self) -> ros_cdk_core.IResolvable:
         '''
@@ -857,12 +1071,12 @@ class RosDomainRecord(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrRecordId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rosProperties")
     def _ros_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "rosProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="domainName")
     def domain_name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -875,18 +1089,30 @@ class RosDomainRecord(
         self,
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "domainName", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enableResourcePropertyConstraint")
     def enable_resource_property_constraint(self) -> builtins.bool:
         return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
 
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        if __debug__:
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rr")
     def rr(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -897,9 +1123,16 @@ class RosDomainRecord(
 
     @rr.setter
     def rr(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "rr", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="type")
     def type(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -909,9 +1142,16 @@ class RosDomainRecord(
 
     @type.setter
     def type(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "type", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="value")
     def value(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -924,9 +1164,16 @@ class RosDomainRecord(
         self,
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "value", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="line")
     def line(
         self,
@@ -941,9 +1188,16 @@ class RosDomainRecord(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "line", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="priority")
     def priority(
         self,
@@ -958,9 +1212,16 @@ class RosDomainRecord(
         self,
         value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "priority", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ttl")
     def ttl(
         self,
@@ -975,6 +1236,13 @@ class RosDomainRecord(
         self,
         value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ttl", value)
 
 
@@ -1013,6 +1281,26 @@ class RosDomainRecordProps:
         :param priority: 
         :param ttl: 
         '''
+        if __debug__:
+            def stub(
+                *,
+                domain_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                rr: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                line: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                priority: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                ttl: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
+            check_type(argname="argument rr", value=rr, expected_type=type_hints["rr"])
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+            check_type(argname="argument line", value=line, expected_type=type_hints["line"])
+            check_type(argname="argument priority", value=priority, expected_type=type_hints["priority"])
+            check_type(argname="argument ttl", value=ttl, expected_type=type_hints["ttl"])
         self._values: typing.Dict[str, typing.Any] = {
             "domain_name": domain_name,
             "rr": rr,
